<?php

namespace Ems\Builders;

use Ems\Services\{ MinhaHistoriaService };

class SolicitacaoPdfBuilder
{
    /**
     * Gera o layout em HTML das solicitações.
     * 
     * Este método recebe um array de solicitações e constrói o HTML correspondente, que será usado posteriormente
     * para gerar um PDF. O HTML gerado contém a estrutura padrão das solicitações, formatada de acordo com um layout específico.
     * 
     * @param array $solicitacoes O array de solicitações que serão usadas para construir o layout.
     * @return string O HTML gerado com as informações das solicitações.
     */
    public function buildHtmlSolicitacaoDefault($solicitacoes): string
    {    
        $labelFieldPessoa = MinhaHistoriaService::$labelFieldPessoa;
        $TIPO_SOLICITACAO_CAMPOS = MinhaHistoriaService::TIPO_SOLICITACAO_CAMPOS;

        // Monta o HTML para o PDF
        $html = "<!DOCTYPE html>
        <html lang=\"pt-BR\">
        <head>
            <meta charset=\"UTF-8\">
            <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">
            <title>Relatório de Solicitação</title>
            <style>
                body { font-family: Arial, sans-serif; margin: 20px; }
                .container { border: 1px solid #000; padding: 15px; margin-bottom: 20px; }
                .header { text-align: center; margin-bottom: 20px; }
                .header h1 { margin: 0; }
                .info { margin-bottom: 15px; }
                .info p { margin: 5px 0; }
                .flex { display: flex; justify-content: space-between; }
                .section-title { font-weight: bold; margin-top: 5px; }
                .separator { margin-top: 5px; border-bottom: 1px solid #000; }
                ul { list-style-type: none; padding: 0; margin: 0; }
                ul li { margin: 5px 0; }
            </style>
        </head>
        <body>";
        
            foreach ($solicitacoes as $solicitacao) {
                $tipoSolicitacao = str_replace('Solicitação de ', '', $solicitacao['NMTIPOSOLICITACAO']);
                $html .= "<div class=\"container\">
                    <div class=\"header\">
                        <h2>Solicitação</h2>
                    </div>
        
                    <div class=\"info\">
                        <p class=\"flex\">
                            <b style='margin-right: 40px;'> Nr. Solicitação: <span style=\"font-size: 20px;\">{$solicitacao['NRSOLICITACAO']}</span></b>
                        </p>
                        <p class=\"flex\">
                            <b style='margin-left: auto;'>Tipo de Solicitação:</b> {$tipoSolicitacao}
                        </p>
                        <p>
                            <b>Solicitante:</b> {$solicitacao['NMOPERADOR']}
                        </p>
                        <p class=\"flex\">
                            <b>
                                Status da Solicitação: 
                                <span style='color:#474A51; margin-right: 60px;'>
                                    {$solicitacao['DSAPROVACAOSEC']}
                                </span>
                            </b>
                            <b>Data da Solicitação:</b> {$solicitacao['DTSOLICITACAO']}
                        </p>
                    </div>

                    <div class=\"separator\"></div>

                    <div class=\"section-title\">Dados da Empresa</div>
                    <div class=\"info\">
                        <p><b>Estrutura Legal:</b> {$solicitacao['NMESTRUTLEGAL']}</p>
                        <p><b>Estrutura Gerencial:</b> {$solicitacao['NMESTRUTGEREN']}</p>
                    </div>

                    <div class=\"separator\"></div>
        
                    <div class=\"section-title\">Dados do Colaborador</div>
                    <div class=\"info\">
                        <p><b>Nr. Vínculo:</b> {$solicitacao['NRVINCULOM']}</p>
                        <p><b>Nome Vínculo:</b> {$solicitacao['NMVINCULOM']}</p>
                    </div>

                    <div class=\"separator\"></div>";
        

                    $camposHistorico = array_filter(
                        $solicitacao,
                        function ($key) {
                            return strpos($key, 'HISTORICO_') === 0; // Verifica se a string começa com 'HISTORICO_'
                        },
                        ARRAY_FILTER_USE_KEY
                    );

                    // Variável para armazenar os itens de histórico
                    $historicoHtml = '';

                    // Itera sobre os campos filtrados
                    foreach ($camposHistorico as $key => $value) {
                        $campo = str_replace('HISTORICO_', '', $key);

                        // Verifica se o campo pertence ao tipo de solicitação e possui label
                        $isCampoTipoSolicitacao = isset($TIPO_SOLICITACAO_CAMPOS[$solicitacao['NRTIPOSOLICITACAO']]) &&
                            in_array($campo, $TIPO_SOLICITACAO_CAMPOS[$solicitacao['NRTIPOSOLICITACAO']], true) &&
                            isset($labelFieldPessoa[$campo]);

                        if ($isCampoTipoSolicitacao) {
                            $label = $labelFieldPessoa[$campo];
                            $historicoHtml .= "<li><b>{$label}:</b> {$value}</li>";
                        }
                    }

                    // Só adiciona a seção de histórico se houver itens
                    if (!empty($historicoHtml)) {
                        $html .= "<div class=\"section-title\">Histórico Atual</div>";
                        $html .= "<ul>{$historicoHtml}</ul>";
                        $html .= "<div class=\"separator\"></div>";
                    };
        
                    $html .= "<div class=\"section-title\">Alterações Solicitadas</div>
                    <ul>";
                
                        // Gerar os itens da seção "Alterações Solicitadas"
                        foreach ($solicitacao['ITENS'] as $item) {
                            $html .= "<li><b>{$item['DSLABELITEMSOLI']}:</b> {$item['DSVALORITEMSOLI']}</li>";
                        }
        
                    $html .= "</ul>

                    <div class=\"separator\"></div>
        
                    <div class=\"section-title\">Justificativa</div>
                    <div class=\"info\">
                        <p>{$solicitacao['DSOBSSOLICITACAO']}</p>
                    </div>

                    <div class=\"separator\"></div>
        
                    <div class=\"section-title\">Fases Aprovação</div>
                    <table 
                        style=\"
                            width: 100%;
                            border-collapse: collapse;
                            border: 1px solid #000;
                            font-size: 14px;
                            margin-top: 10px;
                        \"
                    >
                        <tr>
                            <th style=\"border: 1px solid #000; padding: 8px;\">Fase</th>
                            <th style=\"border: 1px solid #000; padding: 8px;\">Status</th>
                            <th style=\"border: 1px solid #000; padding: 8px;\">Responsável</th>
                            <th style=\"border: 1px solid #000; padding: 8px;\">Aprovado em</th>
                            <th style=\"border: 1px solid #000; padding: 8px;\">Observação</th>
                        </tr>";
        
                        foreach ($solicitacao['FASES'] as $fase) {
                            $html .= "<tr>
                                        <td style=\"border: 1px solid #000; padding: 8px;\">{$fase['NMFASEAPROVSOLI']}</td>
                                        <td style=\"border: 1px solid #000; padding: 8px;\">{$fase['DSAPROVADO']}</td>
                                        <td style=\"border: 1px solid #000; padding: 8px;\">{$fase['NMOPERADOR']}</td>
                                        <td style=\"border: 1px solid #000; padding: 8px;\">{$fase['DTINCLUSAO']}</td>
                                        <td style=\"border: 1px solid #000; padding: 8px;\">{$fase['DSOBSERVACAO']}</td>
                                    </tr>";
                        }
        
                $html .= "</table></div>";
            }
        
        $html .= "</body></html>";

        return $html;
    }

}
